==> cscec5b-ecxj-impl-3.0.0-20230509.073540-32-sources.jar: com/ejianc/business/ecxj/vo/NoticeSuplVO.java <==
package com.ejianc.business.ecxj.vo;

import com.ejianc.framework.skeleton.template.BaseVO;
import com.fasterxml.jackson.annotation.JsonFormat;

import java.math.BigDecimal;
import java.util.ArrayList;
import java.util.Date;
import java.util.List;


/**
 * 供方发送询价填报实体
 * 
 * @author generator
 * 
 */
public class NoticeSuplVO {
    private static final long serialVersionUID = 1L;

    private String id;  // 字符串类型Id
    private String billCode; // 单据编号
    private Integer billState; // 单据状态（审批必须字段）
    private Long lightNoticeId; // 轻量化推送询价单Id
    private Long projectId; // 项目
    private String projectName; // 项目名称
    private String projectSourceId; // 项目来源id
    private Long cropId; // 项目所属组织id
    private String cropName; // 所属公司
    private String cropSourceId; // 项目所属组织来源id
    private Long realCorpId; // NC所属组织ID
    private String realNcCorp; // NC所属组织PK
    private String realCorpName; // NC所属组织名称
    private Long orgId; // 组织
    private String orgSourceId; // 组织来源id
    private String orgName; // 组织名称

    private Long materialTypeId; // 集采材料类型Id
    private String materialTypeName; // 集采材料类型名称
    @JsonFormat(pattern = "yyyy-MM-dd HH:mm:ss", timezone = "GMT+8")
    private Date submitDeadline; // 填报截止日期
    @JsonFormat(pattern = "yyyy-MM-dd HH:mm:ss", timezone = "GMT+8")
    private Date compareTime; // 比选时间

    private Long settingId; // 引用的类型设置Id
    private Long tenderId; // 云筑招标Id
    private String tenderNo; // 云筑招标编号
    private String tenderName; // 云筑招标名称

    private Integer quoteType; // 报价方式
    private String notification; // 通知内容
    private BigDecimal sumMny; // 物资合计金额
    private String createName; // 申请人
    private String supplierSourceId; // 供应商PK
    private String supplierName; // 供应商Id
    private String supplierCreditCode; // 纳税人识别号

    private int submitStatus; // 填报单提交状态，0-未提交，1-已提交，2-已截止，3-已放弃

    private List<NoticeSuplProductVO> noticeSuplProductEntities = new ArrayList<>(); // 通知物资清单实体
    private List<FileVO> fileList = new ArrayList<>(); // 二次询价附件列表

    public String getId() {
        return id;
    }
    public void setId(String id) {
        this.id = id;
    }

    public String getBillCode() {
        return billCode;
    }

    public void setBillCode(String billCode) {
        this.billCode = billCode;
    }
    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }
    public Long getLightNoticeId() {
        return lightNoticeId;
    }

    public void setLightNoticeId(Long lightNoticeId) {
        this.lightNoticeId = lightNoticeId;
    }
    public Long getProjectId() {
        return projectId;
    }

    public void setProjectId(Long projectId) {
        this.projectId = projectId;
    }
    public String getProjectName() {
        return projectName;
    }

    public void setProjectName(String projectName) {
        this.projectName = projectName;
    }
    public String getProjectSourceId() {
        return projectSourceId;
    }

    public void setProjectSourceId(String projectSourceId) {
        this.projectSourceId = projectSourceId;
    }
    public Long getCropId() {
        return cropId;
    }

    public void setCropId(Long cropId) {
        this.cropId = cropId;
    }
    public String getCropName() {
        return cropName;
    }

    public void setCropName(String cropName) {
        this.cropName = cropName;
    }
    public String getCropSourceId() {
        return cropSourceId;
    }

    public void setCropSourceId(String cropSourceId) {
        this.cropSourceId = cropSourceId;
    }
    public Long getRealCorpId() {
        return realCorpId;
    }

    public void setRealCorpId(Long realCorpId) {
        this.realCorpId = realCorpId;
    }
    public String getRealNcCorp() {
        return realNcCorp;
    }

    public void setRealNcCorp(String realNcCorp) {
        this.realNcCorp = realNcCorp;
    }
    public String getRealCorpName() {
        return realCorpName;
    }

    public void setRealCorpName(String realCorpName) {
        this.realCorpName = realCorpName;
    }
    public Long getOrgId() {
        return orgId;
    }

    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }
    public String getOrgSourceId() {
        return orgSourceId;
    }

    public void setOrgSourceId(String orgSourceId) {
        this.orgSourceId = orgSourceId;
    }
    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }
    public Long getMaterialTypeId() {
        return materialTypeId;
    }

    public void setMaterialTypeId(Long materialTypeId) {
        this.materialTypeId = materialTypeId;
    }
    public String getMaterialTypeName() {
        return materialTypeName;
    }

    public void setMaterialTypeName(String materialTypeName) {
        this.materialTypeName = materialTypeName;
    }
    public Date getSubmitDeadline() {
        return submitDeadline;
    }

    public void setSubmitDeadline(Date submitDeadline) {
        this.submitDeadline = submitDeadline;
    }
    public Date getCompareTime() {
        return compareTime;
    }

    public void setCompareTime(Date compareTime) {
        this.compareTime = compareTime;
    }

    public Long getSettingId() {
        return settingId;
    }

    public void setSettingId(Long settingId) {
        this.settingId = settingId;
    }

    public Long getTenderId() {
        return tenderId;
    }

    public void setTenderId(Long tenderId) {
        this.tenderId = tenderId;
    }
    public String getTenderNo() {
        return tenderNo;
    }

    public void setTenderNo(String tenderNo) {
        this.tenderNo = tenderNo;
    }
    public String getTenderName() {
        return tenderName;
    }

    public void setTenderName(String tenderName) {
        this.tenderName = tenderName;
    }
    public Integer getQuoteType() {
        return quoteType;
    }

    public void setQuoteType(Integer quoteType) {
        this.quoteType = quoteType;
    }
    public String getNotification() {
        return notification;
    }

    public void setNotification(String notification) {
        this.notification = notification;
    }
    public BigDecimal getSumMny() {
        return sumMny;
    }

    public void setSumMny(BigDecimal sumMny) {
        this.sumMny = sumMny;
    }
    public String getCreateName() {
        return createName;
    }

    public void setCreateName(String createName) {
        this.createName = createName;
    }

    public String getSupplierSourceId() {
        return supplierSourceId;
    }

    public void setSupplierSourceId(String supplierSourceId) {
        this.supplierSourceId = supplierSourceId;
    }

    public String getSupplierName() {
        return supplierName;
    }

    public void setSupplierName(String supplierName) {
        this.supplierName = supplierName;
    }

    public String getSupplierCreditCode() {
        return supplierCreditCode;
    }

    public void setSupplierCreditCode(String supplierCreditCode) {
        this.supplierCreditCode = supplierCreditCode;
    }

    public int getSubmitStatus() {
        return submitStatus;
    }

    public void setSubmitStatus(int submitStatus) {
        this.submitStatus = submitStatus;
    }

    public List<NoticeSuplProductVO> getNoticeSuplProductEntities() {
        return noticeSuplProductEntities;
    }

    public void setNoticeSuplProductEntities(List<NoticeSuplProductVO> noticeSuplProductEntities) {
        this.noticeSuplProductEntities = noticeSuplProductEntities;
    }

    public List<FileVO> getFileList() {
        return fileList;
    }

    public void setFileList(List<FileVO> fileList) {
        this.fileList = fileList;
    }
}

==> cscec5b-ecxj-impl-3.0.0-20231122.020216-54-sources.jar: com/ejianc/business/ecxj/vo/NoticeSuplVO.java <==
package com.ejianc.business.ecxj.vo;

import com.ejianc.framework.skeleton.template.BaseVO;
import com.fasterxml.jackson.annotation.JsonFormat;

import java.math.BigDecimal;
import java.util.ArrayList;
import java.util.Date;
import java.util.List;


/**
 * 供方发送询价填报实体
 * 
 * @author generator
 * 
 */
public class NoticeSuplVO {
    private static final long serialVersionUID = 1L;

    private String id;  // 字符串类型Id
    private String billCode; // 单据编号
    private Integer billState; // 单据状态（审批必须字段）
    private Long lightNoticeId; // 轻量化推送询价单Id
    private Long projectId; // 项目
    private String projectName; // 项目名称
    private String projectSourceId; // 项目来源id
    private Long cropId; // 项目所属组织id
    private String cropName; // 所属公司
    private String cropSourceId; // 项目所属组织来源id
    private Long realCorpId; // NC所属组织ID
    private String realNcCorp; // NC所属组织PK
    private String realCorpName; // NC所属组织名称
    private Long orgId; // 组织
    private String orgSourceId; // 组织来源id
    private String orgName; // 组织名称

    private Long materialTypeId; // 集采材料类型Id
    private String materialTypeName; // 集采材料类型名称
    @JsonFormat(pattern = "yyyy-MM-dd HH:mm:ss", timezone = "GMT+8")
    private Date submitDeadline; // 填报截止日期
    @JsonFormat(pattern = "yyyy-MM-dd HH:mm:ss", timezone = "GMT+8")
    private Date compareTime; // 比选时间

    private Long settingId; // 引用的类型设置Id
    private Long tenderId; // 云筑招标Id
    private String tenderNo; // 云筑招标编号
    private String tenderName; // 云筑招标名称

    private String productType; // 商品清单类型
    private Integer quoteType; // 报价方式
    private String notification; // 通知内容
    private BigDecimal sumMny; // 物资合计金额
    private String createName; // 申请人
    private String supplierSourceId; // 供应商PK
    private String supplierName; // 供应商Id
    private String supplierCreditCode; // 纳税人识别号

    private int submitStatus; // 填报单提交状态，0-未提交，1-已提交，2-已截止，3-已放弃

    private List<NoticeSuplProductVO> noticeSuplProductEntities = new ArrayList<>(); // 通知物资清单实体
    private List<FileVO> fileList = new ArrayList<>(); // 二次询价附件列表

    public String getId() {
        return id;
    }
    public void setId(String id) {
        this.id = id;
    }

    public String getBillCode() {
        return billCode;
    }

    public void setBillCode(String billCode) {
        this.billCode = billCode;
    }
    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }
    public Long getLightNoticeId() {
        return lightNoticeId;
    }

    public void setLightNoticeId(Long lightNoticeId) {
        this.lightNoticeId = lightNoticeId;
    }
    public Long getProjectId() {
        return projectId;
    }

    public void setProjectId(Long projectId) {
        this.projectId = projectId;
    }
    public String getProjectName() {
        return projectName;
    }

    public void setProjectName(String projectName) {
        this.projectName = projectName;
    }
    public String getProjectSourceId() {
        return projectSourceId;
    }

    public void setProjectSourceId(String projectSourceId) {
        this.projectSourceId = projectSourceId;
    }
    public Long getCropId() {
        return cropId;
    }

    public void setCropId(Long cropId) {
        this.cropId = cropId;
    }
    public String getCropName() {
        return cropName;
    }

    public void setCropName(String cropName) {
        this.cropName = cropName;
    }
    public String getCropSourceId() {
        return cropSourceId;
    }

    public void setCropSourceId(String cropSourceId) {
        this.cropSourceId = cropSourceId;
    }
    public Long getRealCorpId() {
        return realCorpId;
    }

    public void setRealCorpId(Long realCorpId) {
        this.realCorpId = realCorpId;
    }
    public String getRealNcCorp() {
        return realNcCorp;
    }

    public void setRealNcCorp(String realNcCorp) {
        this.realNcCorp = realNcCorp;
    }
    public String getRealCorpName() {
        return realCorpName;
    }

    public void setRealCorpName(String realCorpName) {
        this.realCorpName = realCorpName;
    }
    public Long getOrgId() {
        return orgId;
    }

    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }
    public String getOrgSourceId() {
        return orgSourceId;
    }

    public void setOrgSourceId(String orgSourceId) {
        this.orgSourceId = orgSourceId;
    }
    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }
    public Long getMaterialTypeId() {
        return materialTypeId;
    }

    public void setMaterialTypeId(Long materialTypeId) {
        this.materialTypeId = materialTypeId;
    }
    public String getMaterialTypeName() {
        return materialTypeName;
    }

    public void setMaterialTypeName(String materialTypeName) {
        this.materialTypeName = materialTypeName;
    }
    public Date getSubmitDeadline() {
        return submitDeadline;
    }

    public void setSubmitDeadline(Date submitDeadline) {
        this.submitDeadline = submitDeadline;
    }
    public Date getCompareTime() {
        return compareTime;
    }

    public void setCompareTime(Date compareTime) {
        this.compareTime = compareTime;
    }

    public Long getSettingId() {
        return settingId;
    }

    public void setSettingId(Long settingId) {
        this.settingId = settingId;
    }

    public Long getTenderId() {
        return tenderId;
    }

    public void setTenderId(Long tenderId) {
        this.tenderId = tenderId;
    }
    public String getTenderNo() {
        return tenderNo;
    }

    public void setTenderNo(String tenderNo) {
        this.tenderNo = tenderNo;
    }
    public String getTenderName() {
        return tenderName;
    }

    public void setTenderName(String tenderName) {
        this.tenderName = tenderName;
    }
    public String getProductType() {
        return productType;
    }

    public void setProductType(String productType) {
        this.productType = productType;
    }
    public Integer getQuoteType() {
        return quoteType;
    }

    public void setQuoteType(Integer quoteType) {
        this.quoteType = quoteType;
    }
    public String getNotification() {
        return notification;
    }

    public void setNotification(String notification) {
        this.notification = notification;
    }
    public BigDecimal getSumMny() {
        return sumMny;
    }

    public void setSumMny(BigDecimal sumMny) {
        this.sumMny = sumMny;
    }
    public String getCreateName() {
        return createName;
    }

    public void setCreateName(String createName) {
        this.createName = createName;
    }

    public String getSupplierSourceId() {
        return supplierSourceId;
    }

    public void setSupplierSourceId(String supplierSourceId) {
        this.supplierSourceId = supplierSourceId;
    }

    public String getSupplierName() {
        return supplierName;
    }

    public void setSupplierName(String supplierName) {
        this.supplierName = supplierName;
    }

    public String getSupplierCreditCode() {
        return supplierCreditCode;
    }

    public void setSupplierCreditCode(String supplierCreditCode) {
        this.supplierCreditCode = supplierCreditCode;
    }

    public int getSubmitStatus() {
        return submitStatus;
    }

    public void setSubmitStatus(int submitStatus) {
        this.submitStatus = submitStatus;
    }

    public List<NoticeSuplProductVO> getNoticeSuplProductEntities() {
        return noticeSuplProductEntities;
    }

    public void setNoticeSuplProductEntities(List<NoticeSuplProductVO> noticeSuplProductEntities) {
        this.noticeSuplProductEntities = noticeSuplProductEntities;
    }

    public List<FileVO> getFileList() {
        return fileList;
    }

    public void setFileList(List<FileVO> fileList) {
        this.fileList = fileList;
    }
}
